# Bu araç @keyiflerolsun tarafından | @KekikAkademi için yazılmıştır.

from flet.page import Page, Event

class KekikFlet:
    def __init__(self, sayfa:Page, baslik:str):
        sayfa.title                = baslik
        sayfa.horizontal_alignment = "center"
        sayfa.vertical_alignment   = "center"
        sayfa.theme_mode           = "dark"
        sayfa.scroll               = "adaptive"
        # sayfa.auto_scroll          = True
        sayfa.window_max_width     = 600

        self.sayfa = sayfa

        def kapanirken(event:Event):
            if event.data == "close":
                self.sayfa.window_destroy()

        self.sayfa.window_prevent_close = True
        self.sayfa.on_window_event      = kapanirken
        self.sayfa.update()


# Bu araç @keyiflerolsun tarafından | @KekikAkademi için yazılmıştır.

from ..CLI     import konsol

from flet.page import Page
from flet      import (
    UserControl,
    colors,
    Container,
    padding,
    border,
    border_radius,
    Column,
    Row,
    Image,
    ImageFit,
    ImageRepeat,
    Text,
    TextAlign,
    Divider
)

from ..Libs import sondakika_haberleri, bildirim

class Haberler(UserControl):
    def __init__(self, sayfa:Page, panel:Page):
        super().__init__()
        self.sayfa = sayfa

        self.haberler = sondakika_haberleri()
        panel.araniyor.visible  = False
        panel.cikti_alani.value = f"{len(self.haberler)} adet haber bulundu."
        panel.cikti_alani.color = colors.GREEN_700
        panel.update()
        konsol.print(self.haberler)

        bildirim(
            baslik = "NTV Son Dakika Haberleri",
            icerik = f"{len(self.haberler)} adet haber bulundu."
        )

        self.resimler_satiri = Column(alignment="center", width=350)
        for haber in self.haberler:
            self.resimler_satiri.controls.append(self.__haber_ver(haber))
            self.resimler_satiri.controls.append(Column([Divider()]))
        self.resimler_satiri.controls.pop(-1)

    def build(self):
        return Container(self.resimler_satiri)

    def __haber_ver(self, veri:dict) -> Container:
        return Container(
            Column(
                [
                    Row(
                        [
                            Image(
                                src           = veri["gorsel"],
                                width         = 200,
                                height        = 200,
                                fit           = ImageFit.NONE,
                                repeat        = ImageRepeat.NO_REPEAT,
                                border_radius = border_radius.all(10)
                            )
                        ],
                        alignment="center"
                    ),
                    Row([Text(veri["haber"], size=18, width=300, weight="bold", text_align=TextAlign.CENTER, color=colors.CYAN_700)], alignment="center")
                ]
            ),
            width         = 350,
            padding       = padding.all(10),
            border_radius = border_radius.all(10),
            border        = border.all(width=2, color="#EF7F1A")
        )


# Bu araç @keyiflerolsun tarafından | @KekikAkademi için yazılmıştır.

from flet.page import Page
from flet      import UserControl, Container, Column, Row, Text, ProgressRing, colors

class Panel(UserControl):
    def __init__(self, sayfa:Page):
        super().__init__()
        self.sayfa = sayfa

        self.baslik      = Text("NTV Son Dakika Haberleri", size=22, weight="bold", color="#EF7F1A")
        self.araniyor    = ProgressRing(visible=True)
        self.cikti_alani = Text("Son dakika haberleri aranıyor..", size=18, weight="bold", color=colors.CYAN_700, visible=True)

    def build(self):
        return Container(
            Column(
                [
                    Row([self.baslik],      alignment="center"),
                    Row([self.araniyor],    alignment="center"),
                    Row([self.cikti_alani], alignment="center")
                ]
            )
        )


# Bu araç @keyiflerolsun tarafından | @KekikAkademi için yazılmıştır.

from ..Libs.NTV import sondakika_haberleri
from notifypy   import Notify
from os         import name as sistem
from pathlib    import Path

def bildirim(baslik:str, icerik:str):

    # calisma_dizini = Path(__file__).parent.resolve()

    calisma_dizini = Path(__file__).parents[1]
    ayrac          = "/" if sistem != "nt" else "\\"
    logo_yolu      = f"{calisma_dizini}{ayrac}Assets{ayrac}Logo.png"

    _bildirim = Notify()
    _bildirim._notification_application_name = "ntvHaber | @KekikAkademi"
    _bildirim._notification_icon             = logo_yolu

    if sistem == "nt":
        _bildirim.icon = logo_yolu

    _bildirim.title   = baslik
    _bildirim.message = icerik

    _bildirim.send(block=False)